gedidb.SpatialConsolidationPlan
===============================

.. currentmodule:: gedidb

.. autoclass:: SpatialConsolidationPlan

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SpatialConsolidationPlan.__init__
      ~SpatialConsolidationPlan.dump
      ~SpatialConsolidationPlan.items
   
   

   
   
   